# Training_framework
Training framework for pytorch models

Simple training framework for pytorch  supporting two cases:
- Normal training
- Horovod Training

Use example: [![Open In Colab](https://colab.research.google.com/assets/colab-badge.svg)](https://colab.research.google.com/drive/1MB3dQMWWot8GsMThPe2I4k6jDgw-SqOx?usp=sharing)
